@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
-from typing import List, Tuple
+from typing import List
 
-from monarch_py.datamodels.model import AssociationLabel, FacetValue, SearchResults
+from monarch_py.datamodels.model import AssociationTableResults, FacetValue, SearchResults
 
 
 class SearchInterface(ABC):
@@ -11,13 +11,14 @@ class SearchInterface(ABC):
     def search(
         self,
         q: str,
-        category: str,
-        taxon: str,
         offset: int = 0,
         limit: int = 20,
+        category: List[str] = None,
+        in_taxon: List[str] = None,
         facet_fields: List[str] = None,
         filter_queries: List[str] = None,
         facet_queries: List[str] = None,
+        sort: str = None,
     ) -> SearchResults:
         """
 
@@ -61,8 +62,6 @@ class SearchInterface(ABC):
         object: str = None,
         object_closure: str = None,
         entity: str = None,
-        between: Tuple[str, str] = None,
-        association_label: AssociationLabel = None,
     ) -> SearchResults:
         """
         Get facet counts and facet query counts for associations
@@ -76,7 +75,6 @@ class SearchInterface(ABC):
             object (str): Filter to only associations matching the specified object
             object_closure (str): Filter to only associations with the specified term ID as an ancestor of the object
             entity (str): Filter to only associations where the specified entity is the subject or the object
-            between (Tuple[str, str]): Filter to bi-directional associations between two entities
         Returns:
             SearchResults: Dataclass representing results of a search, with zero rows returned but total count
             and faceting information populated
@@ -92,3 +90,29 @@ class SearchInterface(ABC):
             List[FacetValue]: List of FacetValue objects representing the counts of associations for the given entity
         """
         raise NotImplementedError
+
+    def get_association_table(
+        self,
+        entity: str,
+        category: str,
+        query=None,
+        sort=None,
+        offset=0,
+        limit=5,
+    ) -> AssociationTableResults:
+        """
+        Get associations for an entity matching a specified type, with optional search and sort parameters
+
+        Args:
+            entity (str): Entity to get associations for
+            category (str): Category of associations to return
+            query (str): Query string to match against
+            sort (str): Sort order, defaults to None
+            offset (int): Offset of the first result to return, defaults to 0
+            limit (int): Limit the number of results to return, defaults to 20
+
+        Returns:
+            AssociationResults: Dataclass representing results of an association search.
+        """
+
+        raise NotImplementedError
